@@ -1,11 +1,13 @@
 """Standardised dataclasses for returning resources from storage."""
 import logging
-from typing import Callable, List
+from typing import Callable, List, Optional
 
 import jmespath  # type: ignore
 from botocore import xform_name  # type: ignore
 
+from .boto3_loaders import ServiceMap, ServiceMappingLoader
 from .urn import URN
+from .utils import snake_to_pascal
 
 logger = logging.getLogger(__name__)
 
@@ -54,26 +56,32 @@ class CloudWandererResource:
         urn: URN,
         resource_data: dict,
         secondary_attributes: List["SecondaryAttribute"] = None,
-        loader: Callable = None,
+        loader: Optional[Callable] = None,
         subresource_urns: List[URN] = None,
-        parent_urn: URN = None,
     ) -> None:
         """Initialise the resource.
 
         Arguments:
             urn: The URN of the resource.
             subresource_urns: The URNs of the subresources of this resource.
-            parent_urn: The URN of the parent resource (if one exists)
             resource_data: The dictionary containing the raw data about this resource.
             secondary_attributes: A list of secondary attribute raw dictionaries.
             loader: The method which can be used to fulfil the :meth:`CloudWandererResource.load`.
         """
         self.urn = urn
         self.subresource_urns = subresource_urns or []
-        self.parent_urn = parent_urn
         self.cloudwanderer_metadata = ResourceMetadata(
             resource_data=resource_data or {}, secondary_attributes=secondary_attributes or []
         )
+        service_mapping_loader = ServiceMappingLoader()
+        self.cloudwanderer_service_metadata = ServiceMap.factory(
+            name=urn.service,
+            definition=service_mapping_loader.get_service_mapping(service_name=urn.service),
+        )
+        self.cloudwanderer_resource_metadata = self.cloudwanderer_service_metadata.get_resource_map(
+            snake_to_pascal(urn.resource_type)
+        )
+
         self._loader = loader
         self._set_resource_data_attrs()
 
@@ -98,6 +106,31 @@ class CloudWandererResource:
         """Return whether this resource has all the attributes from storage."""
         return bool([key for key in self.cloudwanderer_metadata.resource_data if not key.startswith("_")])
 
+    @property
+    def is_subresource(self) -> bool:
+        """Return whether this resource is a subresource or not."""
+        return self.cloudwanderer_resource_metadata.type == "subresource"
+
+    @property
+    def parent_urn(self) -> Optional[URN]:
+        if not self.is_subresource:
+            return None
+        parent_resource_type = self.cloudwanderer_resource_metadata.parent_resource_type
+        if not parent_resource_type:
+            raise ValueError(f"{self.urn.resource_type} missing parent resource type in service map.")
+        parent_resource_metadata = jmespath.search(
+            f"resources.{snake_to_pascal(parent_resource_type)}", self.cloudwanderer_service_metadata.boto3_definition
+        )
+        parent_identifiers = parent_resource_metadata.get("identifiers")
+        parent_slice = len(parent_identifiers)
+        return URN(
+            account_id=self.urn.account_id,
+            region=self.urn.region,
+            service=self.urn.service,
+            resource_type=self.cloudwanderer_resource_metadata.parent_resource_type,
+            resource_id_parts=self.urn.resource_id_parts[:parent_slice],
+        )
+
     def get_secondary_attribute(self, name: str = None, jmes_path: str = None) -> List["SecondaryAttribute"]:
         """Get an attribute not returned in the resource's standard ``describe`` method.
 
@@ -125,7 +158,6 @@ class CloudWandererResource:
             f"{self.__class__.__name__}("
             f"urn={repr(self.urn)}, "
             f"subresource_urns={repr(self.subresource_urns)}, "
-            f"parent_urn={repr(self.parent_urn)}, "
             f"resource_data={self.cloudwanderer_metadata.resource_data}, "
             f"secondary_attributes={self.cloudwanderer_metadata.secondary_attributes})"
         )
